#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const degit_1 = __importDefault(require("degit"));
const replace_in_file_1 = __importDefault(require("replace-in-file"));
const node_util_1 = require("node:util");
const node_path_1 = __importDefault(require("node:path"));
const child_process_1 = require("child_process");
const exec = (0, node_util_1.promisify)(child_process_1.exec);
const isWindows = process.platform === "win32";
(() => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    let projectName = (_b = (_a = process.argv[2]) === null || _a === void 0 ? void 0 : _a.trim()) === null || _b === void 0 ? void 0 : _b.replace(" ", "-");
    if (!projectName) {
        console.error(`Please specify a project name:\n  ${chalk_1.default.cyan("create-certified-app")} ${chalk_1.default.green("<project name>")}`);
        process.exit(1);
    }
    const emitter = (0, degit_1.default)("https://github.com/Evam-life/certified-app-template-react", {});
    console.log(`Creating a new certified app in ${chalk_1.default.green(node_path_1.default.join(process.cwd(), projectName))}`);
    yield emitter.clone(projectName);
    try {
        yield (0, replace_in_file_1.default)({
            disableGlobs: true,
            files: [
                node_path_1.default.join(process.cwd(), projectName, "package.json"),
                node_path_1.default.join(process.cwd(), projectName, "public", "evam.json"),
                node_path_1.default.join(process.cwd(), projectName, "index.html"),
            ],
            from: /certified-app-template/g,
            to: projectName,
        });
    }
    catch (e) {
        console.warn(chalk_1.default.yellow `Failed to replace default project name, make sure you update the application ID in ${chalk_1.default.bold(node_path_1.default.join("public", "evam.json"))}. Continuing...`);
    }
    console.log("Installing packages using npm. This might take a while.");
    try {
        yield new Promise((resolve, reject) => {
            const npmInstall = (0, child_process_1.spawn)(isWindows ? "npm.cmd" : "npm", ["install"], {
                cwd: projectName,
                stdio: "inherit",
            });
            npmInstall.on("close", code => {
                if (code === 0)
                    resolve();
                reject();
            });
        });
    }
    catch (e) {
        console.warn(chalk_1.default.yellow `Failed to install packages using npm. You will have to run ${chalk_1.default.bold("npm install")} manually. Continuing...`);
    }
    console.log(""); // Line break after npm output
    try {
        yield exec(`git init`, { cwd: projectName });
        console.log("Initialized a git repository.");
        yield exec(`git add -A`, { cwd: projectName });
        yield exec(`git commit -m "Initialize project from template"`, {
            cwd: projectName,
        });
        console.log("Created git commit.");
    }
    catch (e) {
        console.warn(chalk_1.default.yellow `Git commands failed, continuing...`, e);
    }
    console.log(`${chalk_1.default.green.bold("Success!")} Created ${projectName} at ${node_path_1.default.join(process.cwd(), projectName)}
Inside that directory, you can run several commands:

  ${chalk_1.default.cyan("npm run dev")}
    Starts the development server.
    
  ${chalk_1.default.cyan("npm run build")}
    Bundles the app into static files for production.
    
  ${chalk_1.default.cyan("npm run sideload")}
    Sideloads the app to any connected devices.
    
We suggest that you begin by typing:

  ${chalk_1.default.cyan("cd")} ${projectName}
  ${chalk_1.default.cyan("npm run dev")}
 
Check out up-to-date documentation for the Evam SDK at ${chalk_1.default.blue("https://www.documentation.evam.life")}
Happy hacking!`);
}))();
//# sourceMappingURL=create-certified-app.js.map