import * as z from 'zod';
import { z as z$1 } from 'zod';

declare const appSettingsParser: z$1.ZodRecord<z$1.ZodString, z$1.ZodUnknown>;

declare const locationParser: z.ZodObject<{
    latitude: z.ZodNumber;
    longitude: z.ZodNumber;
    timestamp: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
}, "strip", z.ZodTypeAny, {
    latitude: number;
    longitude: number;
    timestamp?: Date | undefined;
}, {
    latitude: number;
    longitude: number;
    timestamp?: number | Date | undefined;
}>;

declare const operationParser: z.ZodEffects<z.ZodObject<{
    operationID: z.ZodString;
    name: z.ZodString;
    sendTime: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    createdTime: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    endTime: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    acceptedTime: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    callCenterId: z.ZodOptional<z.ZodString>;
    caseFolderId: z.ZodOptional<z.ZodString>;
    transmitterCode: z.ZodOptional<z.ZodString>;
    alarmCategory: z.ZodOptional<z.ZodString>;
    alarmEventCode: z.ZodOptional<z.ZodString>;
    medicalCommander: z.ZodOptional<z.ZodString>;
    medicalIncidentOfficer: z.ZodOptional<z.ZodString>;
    attachedCustomerObject: z.ZodOptional<z.ZodString>;
    alarmEventText: z.ZodOptional<z.ZodString>;
    additionalInfo: z.ZodOptional<z.ZodString>;
    keyNumber: z.ZodOptional<z.ZodString>;
    electronicKey: z.ZodOptional<z.ZodString>;
    radioGroupMain: z.ZodOptional<z.ZodString>;
    radioGroupSecondary: z.ZodOptional<z.ZodString>;
    additionalCoordinationInformation: z.ZodOptional<z.ZodString>;
    availablePriorities: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        id: number;
    }, {
        name: string;
        id: number;
    }>, "many">>;
    patientName: z.ZodOptional<z.ZodString>;
    patientUID: z.ZodOptional<z.ZodString>;
    vehicleStatus: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        event: z.ZodOptional<z.ZodString>;
        successorName: z.ZodOptional<z.ZodString>;
        isStartStatus: z.ZodBoolean;
        isEndStatus: z.ZodBoolean;
        categoryType: z.ZodString;
        categoryName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    }, {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    }>>;
    destinationSiteLocation: z.ZodOptional<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        street: z.ZodOptional<z.ZodString>;
        locality: z.ZodOptional<z.ZodString>;
        municipality: z.ZodOptional<z.ZodString>;
        routeDirections: z.ZodOptional<z.ZodString>;
        pickupTime: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    }, {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    }>>;
    breakpointLocation: z.ZodOptional<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        name: z.ZodOptional<z.ZodString>;
        additionalInfo: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    }, {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    }>>;
    availableHospitalLocations: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodNumber;
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        name: z.ZodOptional<z.ZodString>;
        street1: z.ZodOptional<z.ZodString>;
        city: z.ZodOptional<z.ZodString>;
        region: z.ZodOptional<z.ZodString>;
        postalCode: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }, {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }>, "many">>;
    header1: z.ZodOptional<z.ZodString>;
    header2: z.ZodOptional<z.ZodString>;
    eventInfo: z.ZodOptional<z.ZodString>;
    caseInfo: z.ZodOptional<z.ZodString>;
    selectedHospital: z.ZodOptional<z.ZodNumber>;
    selectedPriority: z.ZodOptional<z.ZodNumber>;
    operationState: z.ZodEnum<["ACTIVE", "AVAILABLE", "COMPLETE"]>;
    leavePatientLocation: z.ZodOptional<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        street: z.ZodOptional<z.ZodString>;
        locality: z.ZodOptional<z.ZodString>;
        municipality: z.ZodOptional<z.ZodString>;
        routeDirections: z.ZodOptional<z.ZodString>;
        leaveTime: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    }, {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    }>>;
    assignedResourceMissionNo: z.ZodOptional<z.ZodString>;
    operationUnits: z.ZodOptional<z.ZodArray<z.ZodObject<{
        unitId: z.ZodString;
        status: z.ZodOptional<z.ZodString>;
        role: z.ZodOptional<z.ZodString>;
        source: z.ZodOptional<z.ZodEnum<["RAKEL", "CLOUD", "UNKNOWN"]>>;
        eta: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
        reportedInArea: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: Date | undefined;
        reportedInArea?: string | undefined;
    }, {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: number | Date | undefined;
        reportedInArea?: string | undefined;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    name: string;
    operationID: string;
    operationState: "ACTIVE" | "AVAILABLE" | "COMPLETE";
    sendTime?: Date | undefined;
    createdTime?: Date | undefined;
    endTime?: Date | undefined;
    acceptedTime?: Date | undefined;
    callCenterId?: string | undefined;
    caseFolderId?: string | undefined;
    transmitterCode?: string | undefined;
    alarmCategory?: string | undefined;
    alarmEventCode?: string | undefined;
    medicalCommander?: string | undefined;
    medicalIncidentOfficer?: string | undefined;
    attachedCustomerObject?: string | undefined;
    alarmEventText?: string | undefined;
    additionalInfo?: string | undefined;
    keyNumber?: string | undefined;
    electronicKey?: string | undefined;
    radioGroupMain?: string | undefined;
    radioGroupSecondary?: string | undefined;
    additionalCoordinationInformation?: string | undefined;
    availablePriorities?: {
        name: string;
        id: number;
    }[] | undefined;
    patientName?: string | undefined;
    patientUID?: string | undefined;
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    destinationSiteLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    } | undefined;
    breakpointLocation?: {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    } | undefined;
    availableHospitalLocations?: {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }[] | undefined;
    header1?: string | undefined;
    header2?: string | undefined;
    eventInfo?: string | undefined;
    caseInfo?: string | undefined;
    selectedHospital?: number | undefined;
    selectedPriority?: number | undefined;
    leavePatientLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    } | undefined;
    assignedResourceMissionNo?: string | undefined;
    operationUnits?: {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: Date | undefined;
        reportedInArea?: string | undefined;
    }[] | undefined;
}, {
    name: string;
    operationID: string;
    operationState: "ACTIVE" | "AVAILABLE" | "COMPLETE";
    sendTime?: number | Date | undefined;
    createdTime?: number | Date | undefined;
    endTime?: number | Date | undefined;
    acceptedTime?: number | Date | undefined;
    callCenterId?: string | undefined;
    caseFolderId?: string | undefined;
    transmitterCode?: string | undefined;
    alarmCategory?: string | undefined;
    alarmEventCode?: string | undefined;
    medicalCommander?: string | undefined;
    medicalIncidentOfficer?: string | undefined;
    attachedCustomerObject?: string | undefined;
    alarmEventText?: string | undefined;
    additionalInfo?: string | undefined;
    keyNumber?: string | undefined;
    electronicKey?: string | undefined;
    radioGroupMain?: string | undefined;
    radioGroupSecondary?: string | undefined;
    additionalCoordinationInformation?: string | undefined;
    availablePriorities?: {
        name: string;
        id: number;
    }[] | undefined;
    patientName?: string | undefined;
    patientUID?: string | undefined;
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    destinationSiteLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    } | undefined;
    breakpointLocation?: {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    } | undefined;
    availableHospitalLocations?: {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }[] | undefined;
    header1?: string | undefined;
    header2?: string | undefined;
    eventInfo?: string | undefined;
    caseInfo?: string | undefined;
    selectedHospital?: number | undefined;
    selectedPriority?: number | undefined;
    leavePatientLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    } | undefined;
    assignedResourceMissionNo?: string | undefined;
    operationUnits?: {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: number | Date | undefined;
        reportedInArea?: string | undefined;
    }[] | undefined;
}>, {
    name: string;
    operationID: string;
    operationState: "ACTIVE" | "AVAILABLE" | "COMPLETE";
    sendTime?: Date | undefined;
    createdTime?: Date | undefined;
    endTime?: Date | undefined;
    acceptedTime?: Date | undefined;
    callCenterId?: string | undefined;
    caseFolderId?: string | undefined;
    transmitterCode?: string | undefined;
    alarmCategory?: string | undefined;
    alarmEventCode?: string | undefined;
    medicalCommander?: string | undefined;
    medicalIncidentOfficer?: string | undefined;
    attachedCustomerObject?: string | undefined;
    alarmEventText?: string | undefined;
    additionalInfo?: string | undefined;
    keyNumber?: string | undefined;
    electronicKey?: string | undefined;
    radioGroupMain?: string | undefined;
    radioGroupSecondary?: string | undefined;
    additionalCoordinationInformation?: string | undefined;
    availablePriorities?: {
        name: string;
        id: number;
    }[] | undefined;
    patientName?: string | undefined;
    patientUID?: string | undefined;
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    destinationSiteLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    } | undefined;
    breakpointLocation?: {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    } | undefined;
    availableHospitalLocations?: {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }[] | undefined;
    header1?: string | undefined;
    header2?: string | undefined;
    eventInfo?: string | undefined;
    caseInfo?: string | undefined;
    selectedHospital?: number | undefined;
    selectedPriority?: number | undefined;
    leavePatientLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    } | undefined;
    assignedResourceMissionNo?: string | undefined;
    operationUnits?: {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: Date | undefined;
        reportedInArea?: string | undefined;
    }[] | undefined;
    operationFullId: string;
}, {
    name: string;
    operationID: string;
    operationState: "ACTIVE" | "AVAILABLE" | "COMPLETE";
    sendTime?: number | Date | undefined;
    createdTime?: number | Date | undefined;
    endTime?: number | Date | undefined;
    acceptedTime?: number | Date | undefined;
    callCenterId?: string | undefined;
    caseFolderId?: string | undefined;
    transmitterCode?: string | undefined;
    alarmCategory?: string | undefined;
    alarmEventCode?: string | undefined;
    medicalCommander?: string | undefined;
    medicalIncidentOfficer?: string | undefined;
    attachedCustomerObject?: string | undefined;
    alarmEventText?: string | undefined;
    additionalInfo?: string | undefined;
    keyNumber?: string | undefined;
    electronicKey?: string | undefined;
    radioGroupMain?: string | undefined;
    radioGroupSecondary?: string | undefined;
    additionalCoordinationInformation?: string | undefined;
    availablePriorities?: {
        name: string;
        id: number;
    }[] | undefined;
    patientName?: string | undefined;
    patientUID?: string | undefined;
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    destinationSiteLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        pickupTime?: string | undefined;
    } | undefined;
    breakpointLocation?: {
        latitude: number;
        longitude: number;
        name?: string | undefined;
        additionalInfo?: string | undefined;
    } | undefined;
    availableHospitalLocations?: {
        latitude: number;
        longitude: number;
        id: number;
        name?: string | undefined;
        street1?: string | undefined;
        city?: string | undefined;
        region?: string | undefined;
        postalCode?: string | undefined;
    }[] | undefined;
    header1?: string | undefined;
    header2?: string | undefined;
    eventInfo?: string | undefined;
    caseInfo?: string | undefined;
    selectedHospital?: number | undefined;
    selectedPriority?: number | undefined;
    leavePatientLocation?: {
        latitude: number;
        longitude: number;
        street?: string | undefined;
        locality?: string | undefined;
        municipality?: string | undefined;
        routeDirections?: string | undefined;
        leaveTime?: string | undefined;
    } | undefined;
    assignedResourceMissionNo?: string | undefined;
    operationUnits?: {
        unitId: string;
        status?: string | undefined;
        role?: string | undefined;
        source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
        eta?: number | Date | undefined;
        reportedInArea?: string | undefined;
    }[] | undefined;
}>;

declare const tripLocationHistoryParser: z.ZodObject<{
    locationHistory: z.ZodArray<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        timestamp: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        timestamp?: Date | undefined;
    }, {
        latitude: number;
        longitude: number;
        timestamp?: number | Date | undefined;
    }>, "many">;
    etaSeconds: z.ZodOptional<z.ZodNumber>;
    distanceToDestinationMeters: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    locationHistory: {
        latitude: number;
        longitude: number;
        timestamp?: Date | undefined;
    }[];
    etaSeconds?: number | undefined;
    distanceToDestinationMeters?: number | undefined;
}, {
    locationHistory: {
        latitude: number;
        longitude: number;
        timestamp?: number | Date | undefined;
    }[];
    etaSeconds?: number | undefined;
    distanceToDestinationMeters?: number | undefined;
}>;

declare const rakelStateParser: z.ZodObject<{
    msisdn: z.ZodOptional<z.ZodString>;
    issi: z.ZodOptional<z.ZodString>;
    gssi: z.ZodOptional<z.ZodString>;
    isHealthy: z.ZodBoolean;
}, "strict", z.ZodTypeAny, {
    isHealthy: boolean;
    msisdn?: string | undefined;
    issi?: string | undefined;
    gssi?: string | undefined;
}, {
    isHealthy: boolean;
    msisdn?: string | undefined;
    issi?: string | undefined;
    gssi?: string | undefined;
}>;

declare const vehicleStatusParser: z.ZodObject<{
    name: z.ZodString;
    event: z.ZodOptional<z.ZodString>;
    successorName: z.ZodOptional<z.ZodString>;
    isStartStatus: z.ZodBoolean;
    isEndStatus: z.ZodBoolean;
    categoryType: z.ZodString;
    categoryName: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    isStartStatus: boolean;
    isEndStatus: boolean;
    categoryType: string;
    categoryName: string;
    event?: string | undefined;
    successorName?: string | undefined;
}, {
    name: string;
    isStartStatus: boolean;
    isEndStatus: boolean;
    categoryType: string;
    categoryName: string;
    event?: string | undefined;
    successorName?: string | undefined;
}>;

declare const vehicleStateParser: z.ZodObject<{
    timestamp: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>;
    vehicleStatus: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        event: z.ZodOptional<z.ZodString>;
        successorName: z.ZodOptional<z.ZodString>;
        isStartStatus: z.ZodBoolean;
        isEndStatus: z.ZodBoolean;
        categoryType: z.ZodString;
        categoryName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    }, {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    }>>;
    activeCaseFullId: z.ZodOptional<z.ZodString>;
    vehicleLocation: z.ZodOptional<z.ZodObject<{
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        timestamp: z.ZodOptional<z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodNumber, number, number>, Date, number>, z.ZodDate]>>;
    }, "strip", z.ZodTypeAny, {
        latitude: number;
        longitude: number;
        timestamp?: Date | undefined;
    }, {
        latitude: number;
        longitude: number;
        timestamp?: number | Date | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    timestamp: Date;
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    activeCaseFullId?: string | undefined;
    vehicleLocation?: {
        latitude: number;
        longitude: number;
        timestamp?: Date | undefined;
    } | undefined;
}, {
    timestamp: (number | Date) & (number | Date | undefined);
    vehicleStatus?: {
        name: string;
        isStartStatus: boolean;
        isEndStatus: boolean;
        categoryType: string;
        categoryName: string;
        event?: string | undefined;
        successorName?: string | undefined;
    } | undefined;
    activeCaseFullId?: string | undefined;
    vehicleLocation?: {
        latitude: number;
        longitude: number;
        timestamp?: number | Date | undefined;
    } | undefined;
}>;

declare const batteryParser: z.ZodObject<{
    health: z.ZodOptional<z.ZodEnum<["UNKNOWN", "GOOD", "OVERHEAT", "DEAD", "OVER_VOLTAGE", "UNSPECIFIED_FAILURE", "COLD"]>>;
    plugged: z.ZodOptional<z.ZodEnum<["DOCK", "AC", "USB", "WIRELESS"]>>;
    status: z.ZodOptional<z.ZodEnum<["UNKNOWN", "CHARGING", "DISCHARGING", "NOT_CHARGING", "FULL"]>>;
    capacity: z.ZodOptional<z.ZodNumber>;
}, "strict", z.ZodTypeAny, {
    health?: "UNKNOWN" | "GOOD" | "OVERHEAT" | "DEAD" | "OVER_VOLTAGE" | "UNSPECIFIED_FAILURE" | "COLD" | undefined;
    plugged?: "DOCK" | "AC" | "USB" | "WIRELESS" | undefined;
    status?: "UNKNOWN" | "CHARGING" | "DISCHARGING" | "NOT_CHARGING" | "FULL" | undefined;
    capacity?: number | undefined;
}, {
    health?: "UNKNOWN" | "GOOD" | "OVERHEAT" | "DEAD" | "OVER_VOLTAGE" | "UNSPECIFIED_FAILURE" | "COLD" | undefined;
    plugged?: "DOCK" | "AC" | "USB" | "WIRELESS" | undefined;
    status?: "UNKNOWN" | "CHARGING" | "DISCHARGING" | "NOT_CHARGING" | "FULL" | undefined;
    capacity?: number | undefined;
}>;

declare const operationPriorityParser: z.ZodObject<{
    id: z.ZodNumber;
    name: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    id: number;
}, {
    name: string;
    id: number;
}>;

declare const destinationSiteLocationParser: z.ZodObject<{
    latitude: z.ZodNumber;
    longitude: z.ZodNumber;
    street: z.ZodOptional<z.ZodString>;
    locality: z.ZodOptional<z.ZodString>;
    municipality: z.ZodOptional<z.ZodString>;
    routeDirections: z.ZodOptional<z.ZodString>;
    pickupTime: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    latitude: number;
    longitude: number;
    street?: string | undefined;
    locality?: string | undefined;
    municipality?: string | undefined;
    routeDirections?: string | undefined;
    pickupTime?: string | undefined;
}, {
    latitude: number;
    longitude: number;
    street?: string | undefined;
    locality?: string | undefined;
    municipality?: string | undefined;
    routeDirections?: string | undefined;
    pickupTime?: string | undefined;
}>;

declare const hospitalLocationParser: z.ZodObject<{
    id: z.ZodNumber;
    latitude: z.ZodNumber;
    longitude: z.ZodNumber;
    name: z.ZodOptional<z.ZodString>;
    street1: z.ZodOptional<z.ZodString>;
    city: z.ZodOptional<z.ZodString>;
    region: z.ZodOptional<z.ZodString>;
    postalCode: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    latitude: number;
    longitude: number;
    id: number;
    name?: string | undefined;
    street1?: string | undefined;
    city?: string | undefined;
    region?: string | undefined;
    postalCode?: string | undefined;
}, {
    latitude: number;
    longitude: number;
    id: number;
    name?: string | undefined;
    street1?: string | undefined;
    city?: string | undefined;
    region?: string | undefined;
    postalCode?: string | undefined;
}>;

declare const destinationControlPointLocationParser: z.ZodObject<{
    latitude: z.ZodNumber;
    longitude: z.ZodNumber;
    name: z.ZodOptional<z.ZodString>;
    additionalInfo: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    latitude: number;
    longitude: number;
    name?: string | undefined;
    additionalInfo?: string | undefined;
}, {
    latitude: number;
    longitude: number;
    name?: string | undefined;
    additionalInfo?: string | undefined;
}>;

declare const deviceRoleParser: z.ZodEnum<["SINGLE_DEVICE", "RECEIVING_DEVICE", "MAIN_DEVICE"]>;

declare const displayModeParser: z.ZodEnum<["LIGHT", "DARK"]>;

declare const osVersionParser: z.ZodString;

declare const vehicleServicesNotificationIdParser: z.ZodString;

declare const appVersionParser: z.ZodString;

declare const deviceIdParser: z.ZodString;

declare const appIdParser: z.ZodString;

declare const grpcAddressParser: z.ZodString;

declare const batteryHealthParser: z.ZodEnum<["UNKNOWN", "GOOD", "OVERHEAT", "DEAD", "OVER_VOLTAGE", "UNSPECIFIED_FAILURE", "COLD"]>;

declare const batteryPluggedParser: z.ZodEnum<["DOCK", "AC", "USB", "WIRELESS"]>;

declare const batteryStatusParser: z.ZodEnum<["UNKNOWN", "CHARGING", "DISCHARGING", "NOT_CHARGING", "FULL"]>;

declare const operationStateParser: z$1.ZodEnum<["ACTIVE", "AVAILABLE", "COMPLETE"]>;

declare const vehicleServicesCallbackIdSuffixParser: z$1.ZodUnion<[z$1.ZodLiteral<"-p">, z$1.ZodLiteral<"-s">]>;

declare const rakelMessagesParser: z.ZodArray<z.ZodString, "many">;

declare const operationUnitSourceParser: z$1.ZodEnum<["RAKEL", "CLOUD", "UNKNOWN"]>;

declare const operationUnitParser: z$1.ZodObject<{
    unitId: z$1.ZodString;
    status: z$1.ZodOptional<z$1.ZodString>;
    role: z$1.ZodOptional<z$1.ZodString>;
    source: z$1.ZodOptional<z$1.ZodEnum<["RAKEL", "CLOUD", "UNKNOWN"]>>;
    eta: z$1.ZodOptional<z$1.ZodUnion<[z$1.ZodEffects<z$1.ZodEffects<z$1.ZodNumber, number, number>, Date, number>, z$1.ZodDate]>>;
    reportedInArea: z$1.ZodOptional<z$1.ZodString>;
}, "strip", z$1.ZodTypeAny, {
    unitId: string;
    status?: string | undefined;
    role?: string | undefined;
    source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
    eta?: Date | undefined;
    reportedInArea?: string | undefined;
}, {
    unitId: string;
    status?: string | undefined;
    role?: string | undefined;
    source?: "UNKNOWN" | "RAKEL" | "CLOUD" | undefined;
    eta?: number | Date | undefined;
    reportedInArea?: string | undefined;
}>;

/**
 * ID of the certified application
 */
type AppId = z.infer<typeof appIdParser>;

/**
 * The app settings for the Vehicle Service's logged in Vehicle
 */
type AppSettings = z$1.infer<typeof appSettingsParser>;

/**
 * The version of Vehicle Services
 */
type AppVersion = z.infer<typeof appVersionParser>;

/**
 * Represents the current Battery state
 * @property {BatteryHealth | undefined} health - The health status of the battery.
 * @property {BatteryStatus | undefined} status - The charging state of the battery.
 * @property {number | undefined} capacity - The remaining charge in the battery.
 * @property {BatteryPlugged | undefined} plugged - The plugged status of the battery.
 */
type Battery = z.infer<typeof batteryParser>;

/**
 * ID of the Android Devices
 */
type DeviceId = z.infer<typeof deviceIdParser>;

/**
 * Role of the Vehicle Services application.
 */
type DeviceRole = z$1.infer<typeof deviceRoleParser>;

/**
 * The display mode (either light or dark).
 */
type DisplayMode = z$1.infer<typeof displayModeParser>;

/**
 * The gRPC address of the proxy
 */
type GrpcAddress = z.infer<typeof grpcAddressParser>;

declare const internetStateParser: z$1.ZodEnum<["NO_INTERNET", "CONNECTED_2G", "CONNECTED_EDGE", "CONNECTED_3G", "CONNECTED_4G", "CONNECTED_5G", "CONNECTED_WIFI"]>;
/**
 * Represent the state of the internet connection
 */
type InternetState = z$1.infer<typeof internetStateParser>;

/**
 * An operation currently stored in the Operation List.
 * @property operationID The operation ID
 * @property name The operation name
 * @property sendTime The time at which the operation was sent
 * @property createdTime The time at which the operation was created
 * @property acceptedTime The time at which the operation was accepted (PREVIEW)
 * @property endTime The time at which the operation ended, `undefined` still ongoing
 * @property callCenterId The Call Center ID
 * @property caseFolderId The Case folder ID
 * @property transmitterCode The transmitter code
 * @property alarmCategory The alarm category
 * @property alarmEventCode The alarm event code
 * @property medicalCommander The medical commander of this operation
 * @property medicalIncidentOfficer The medical incident office of this operation
 * @property attachedCustomerObject The attached customer Object
 * @property alarmEventText The alarm event text
 * @property additionalInfo The additional information attached to this operation
 * @property keyNumber The key number
 * @property electronicKey The electronic key
 * @property radioGroupMain The main radio group associated with this operation
 * @property radioGroupSecondary The secondary radio group associated with this operation
 * @property additionalCoordinationInformation Additional coordination information
 * @property availablePriorities The list of available priorities to select from
 * @property patientName The name of the patient if any
 * @property patientUID The personal number of the patient if any
 * @property vehicleStatus The current vehicle status in this operation
 * @property destinationSiteLocation The location of the destination
 * @property breakpointLocation The location of the breakpoint if any
 * @property availableHospitalLocations The list of available hospitals to select from
 * @property header1 The case index 2
 * @property header2 The case index 3
 * @property eventInfo The event description
 * @property caseInfo The case info comment
 * @property selectedHospital The id of the selected hospital [inside available hospitals]
 * @property selectedPriority The id of the selected priority [inside available priority]
 * @property operationState the current state of the operation (ACTIVE, AVAILABLE, COMPLETE)
 * @property leavePatientLocation The location of the leave-patient ('toCity', etc)
 */
type Operation = z.infer<typeof operationParser>;

/**
 * The Operation List represents all the currently stored operations in Vehicle Services.
 * The Operation List may contain operations which are "ACTIVE", "AVAILABLE", "COMPLETE".
 */
type OperationList = Array<Operation>;

/**
 * The OS version of the Android device.
 */
type OSVersion = z.infer<typeof osVersionParser>;

/**
 * General information about the current Rakel radio state
 * @property issi The radio ISSI
 * @property msisdn The radio MSISDN
 * @property gssi The radio GSSI
 */
type RakelState = z.infer<typeof rakelStateParser>;

/**
 * The history of locations for a given operation.
 * @property {Array<Location>} locationHistory an array of locations representing the trip
 * @property {number | undefined} etaSeconds the estimated time of arrival in the operation destination
 * @property {number | undefined} distanceToDestinationMeters the distance from the operation destination.
 */
type TripLocationHistory = z.infer<typeof tripLocationHistoryParser>;

/**
 * The version of Vehicle Services
 */
type VehicleServicesVersion = z.infer<typeof vehicleServicesNotificationIdParser>;

/**
 * State of the vehicle, location, status, id
 * @property {Date} timestamp the date of when state received
 * @property {VehicleStatus} vehicleStatus the status of the vehicle
 * @see VehicleStatus
 * @property {string} activeCaseFullId id of the current active operation
 * @property {Location} vehicleLocation the current vehicle location
 */
type VehicleState = z.infer<typeof vehicleStateParser>;

/**
 * Vehicle status
 * @property name The name of the vehicle status
 * @property event The event associated to this status, if any
 * @property successorName The name of a typical successor to this status based on vehicle configuration
 * @property isStartStatus true if this status is engaged at the start of a new operation
 * @property isEndStatus true if this status closes the current operation
 * @property categoryType Type if status: 'mission' or 'other'
 * @property categoryName The name of the category as defined by the vehicle user
 */
type VehicleStatus = z.infer<typeof vehicleStatusParser>;

type VehicleStatusList = Array<VehicleStatus>;

/**
 * Represents a location on the map at a specific point in time.
 * @typedef {Object} Location
 * @property {number} latitude - The latitude coordinate.
 * @property {number} longitude - The longitude coordinate.
 * @property {Date | undefined} timestamp - The timestamp the given location was received.
 */
type Location = z.infer<typeof locationParser>;

/**
 * Messages from the connected Rakel radio
 */
type RakelMessages = z.infer<typeof rakelMessagesParser>;

/**
 * An interface which maps a VehicleServicesEvent to its payload parser.
 * This is for compile-time typechecking.
 */
interface VehicleServicesEventPayloadInterface {
    /**
     * Event which will often trigger with the current location of the vehicle.
     * @see Location
     */
    newOrUpdatedLocation: Location | undefined;
    /**
     * Event which will trigger when the state of the operation changes.
     * @example the operation closes
     * @example the case info updates
     * @example the active operation is 50506closed and this payload will be undefined
     * @see Operation
     */
    newOrUpdatedOperation: Operation | undefined;
    /**
     * Event which will trigger passing the settings fetched from the backend.
     */
    newOrUpdatedSettings: AppSettings | undefined;
    /**
     * Event which will trigger when the internet connection state changes.
     * @example connection to Wi-Fi
     * @example loss of connection
     * @see InternetState
     */
    newOrUpdatedInternetState: InternetState | undefined;
    /**
     * Event which will trigger with the device's role as the payload.
     * @example SINGLE_DEVICE
     * @see DeviceRole
     */
    newOrUpdatedDeviceRole: DeviceRole | undefined;
    /**
     * The "VehicleState" will update with new information regarding the status of the vehicle as well as the current location and the current active case Id.
     * @see VehicleStatus
     */
    newOrUpdatedVehicleState: VehicleState | undefined;
    /**
     * Event which triggers when the state of the trip location history updates.
     * @example when the current location updates
     */
    newOrUpdatedTripLocationHistory: TripLocationHistory | undefined;
    /**
     * Event which triggers when the state of the Rakel system changes.
     * @example the tablet is disconnected from the radio.
     */
    newOrUpdateRakelState: RakelState | undefined;
    /**
     * Event which triggers when new rakel messages are received from the radio.
     */
    newOrUpdatedRakelMessages: RakelMessages | undefined;
    /**
     * Event which triggers initially
     */
    newOrUpdatedAvailableVehicleStatusList: VehicleStatusList | undefined;
    /**
     * Event which triggers when the state of the list of operations change.
     * @example when a case closes or a new case appear.
     */
    newOrUpdatedOperationList: OperationList | undefined;
    /**
     * Event which triggers when the state of the battery is updated.
     * @example when the battery's level depletes.
     */
    newOrUpdatedBattery: Battery | undefined;
    /**
     * Event which triggers when the display mode in the app updates.
     * This will occur when the user manually changes the display mode OR
     * when Vehicle Services display mode is set to 'auto' from the system.
     */
    newOrUpdatedDisplayMode: DisplayMode | undefined;
    /**
     * Event which triggers once with the Vehicle Services version
     */
    vehicleServicesVersionSet: VehicleServicesVersion | undefined;
    /**
     * Event which triggers once with the Android OS version
     */
    osVersionSet: OSVersion | undefined;
    /**
     * Event which triggers once with the version of your certified application.
     */
    appVersionSet: AppVersion | undefined;
    /**
     * Event which triggers once with the ID of the device
     */
    deviceIdSet: DeviceId | undefined;
    /**
     * Event which triggers once with the ID of the application
     */
    appIdSet: AppId | undefined;
    /**
     * Event which wil trigger with the gRPC address when the gRPC server has been established.
     */
    gRPCEstablished: GrpcAddress | undefined;
}

declare const notificationTypeParser: z$1.ZodEnum<["LASTING_HUN", "CONCEALED_HUN", "LIMITED_HUN", "QUICK_HUN", "ACTION_HUN"]>;
/**
 * The type of notification (which determines how it is displayed)
 */
type NotificationType = z$1.infer<typeof notificationTypeParser>;

/**
 * Represents a button on a VehicleServices notification.
 * @property {string} label the label of the button
 * @property {() => void} callback the function that will trigger on clicking the button.
 * @see EvamApi.prototype.notification
 */
type VehicleServicesNotificationButton = {
    label: string;
    callback: () => void;
};

/**
 * A notification which can be sent to Vehicle Services
 * @property {string} heading the heading of the notification (i.e. the title)
 * @property {string} description the notification description
 * @property {NotificationType} type the type of the notification (which will determine how it displays)
 * @property {VehicleServicesNotificationButton} primaryButton the primary button
 * @property {VehicleServicesNotificationButton | undefined} primaryButton the (optional) secondary button
 * @see VehicleServicesNotificationButton
 */
type VehicleServicesNotification = {
    heading: string;
    description: string;
    notificationType: NotificationType;
    primaryButton: VehicleServicesNotificationButton;
    secondaryButton?: VehicleServicesNotificationButton;
    notificationId?: string;
};

/**
 * A uuid of a sent VehicleServicesNotification
 */
type VehicleServicesNotificationId = z.infer<typeof vehicleServicesNotificationIdParser>;

/**
 * @ignore
 */
type VehicleServicesCallbackIdSuffix = z$1.infer<typeof vehicleServicesCallbackIdSuffixParser>;

/**
 * The id of a callback inside the SDK. This is generated when a notification is sent.
 * Primary callbacks are suffixed with "-p" whereas secondary "-s"
 */
type VehicleServicesNotificationCallbackId = `${VehicleServicesNotificationId}${VehicleServicesCallbackIdSuffix}`;

type _InternalVehicleServicesNotification = Omit<VehicleServicesNotification, "secondaryButton" | "primaryButton"> & {
    primaryButton: {
        label: string;
        callback: VehicleServicesNotificationCallbackId;
    };
    secondaryButton?: {
        label: string;
        callback: VehicleServicesNotificationCallbackId;
    };
};

interface _InternalVehicleServicesEventPayloadInterface {
    rawRakelActionSent: string | undefined;
    vehicleServicesNotificationSent: _InternalVehicleServicesNotification | undefined;
    navLayerPointSet: string | undefined;
    navLayerShapeSet: string | undefined;
    navLayerDeleted: string | undefined;
    apiReady: undefined;
    vehicleServicesNotificationCallbackTriggered: VehicleServicesNotificationCallbackId | undefined;
}

/**
 * Represents the current state of an Operation.
 */
type OperationState = z$1.infer<typeof operationStateParser>;

/**
 * Location of a hospital
 * @property {number} id Hospital unique ID
 * @property {number} latitude the latitude of hospital location
 * @property {number} longitude the longitude of hospital location
 * @property {string | undefined} name the name of hospital
 * @property {string | undefined} street1 the street address of hospital
 * @property {string | undefined} city the city in which hospital is located
 * @property {string | undefined} region the region in which hospital is located
 * @property {string | undefined} postalCode the postal code of hospital
 */
type HospitalLocation = z.infer<typeof hospitalLocationParser>;

/**
 * Location of a breakpoint
 * @param latitude Latitude in decimal degrees
 * @param longitude Longitude in decimal degrees
 * @param name Breakpoint name if available
 * @param additionalInfo Additional information if available
 */
type DestinationControlPointLocation = z.infer<typeof destinationControlPointLocationParser>;

/**
 * Selectable operation priority
 * @property id id of the priority
 * @property name name of the priority
 */
type OperationPriority = z$1.infer<typeof operationPriorityParser>;

/**
 * Represents a latitude longitude pair of coordinates.
 * @property {number} latitude the latitude coordinate.
 * @property {longitude} the longitude coordinate.
 */
type LatLon = {
    latitude: number;
    longitude: number;
};

/**
 * A singular  for drawing a point layer on the map.
 * @property {LatLon} point the latitude, longitude coordinates to draw the point.
 * @property {string} text the text to display on the point.
 * @property {string} icon the icon to draw on the point (based on the name of a Material Design icon)
 */
type LayerPoint = {
    point: LatLon;
    text: string;
    icon: string;
};

/**
 * A singular  for drawing a shape layer on the map.
 * @property {LatLon} points the latitude, longitude coordinates representing the points to draw the shape.
 * @property {string} text the text to display on the shape.
 * @property {string} color the hex color of the shape.
 */
type LayerShape = {
    points: LatLon[];
    text: string;
    color: string;
};

/**
 * Represents the health of a battery.
 */
type BatteryHealth = z$1.infer<typeof batteryHealthParser>;

/**
 * The plugged status of a battery.
 */
type BatteryPlugged = z$1.infer<typeof batteryPluggedParser>;

/**
 * The charging status of a battery.
 */
type BatteryStatus = z$1.infer<typeof batteryStatusParser>;

/**
 * Location of a destination site
 * @param latitude Latitude in decimal degrees
 * @param longitude Longitude in decimal degrees
 * @param street The street name if available
 * @param locality The locality name if available
 * @param municipality The municipality name if available
 * @param routeDirections The route directions text if available
 * @param pickupTime The pickup time text if available
 */
type DestinationSiteLocation = z$1.infer<typeof destinationSiteLocationParser>;

type EventInterfaceType = Record<string, any>;

type EventType<K extends EventInterfaceType> = keyof K;

type EventPayloadType<I extends EventInterfaceType, E extends EventType<I>> = I[E];

type _InternalVehicleServicesEvent = EventType<_InternalVehicleServicesEventPayloadInterface>;

type _InternalVehicleServicesEventPayload<E extends _InternalVehicleServicesEvent> = EventPayloadType<_InternalVehicleServicesEventPayloadInterface, E>;

type NotificationCallbackType = "primary" | "secondary";

/**
 * A subscribable event in Vehicle Services
 * @see EvamApi.prototype.on
 * @see VehicleServicesEventPayloadInterface
 */
type VehicleServicesEvent = EventType<VehicleServicesEventPayloadInterface>;

/**
 * A payload associated with a Vehicle Services event.
 * When a VehicleServicesEvent is dispatched it will have a payload.
 * @example "newOrUpdatedOperation" event has payload of type Operation (or undefined)
 * @see VehicleServicesEvent
 */
type VehicleServicesEventPayload<E extends VehicleServicesEvent> = EventPayloadType<VehicleServicesEventPayloadInterface, E>;

type OperationUnit = z$1.infer<typeof operationUnitParser>;

type OperationUnitSource = z$1.infer<typeof operationUnitSourceParser>;

declare const EvamApi: {
    isRunningInVehicleServices: boolean;
    event: {
        on: <E extends keyof VehicleServicesEventPayloadInterface>(event: E, callback: (payload: VehicleServicesEventPayload<E>) => void, { immediatelyInvoke, }?: {
            immediatelyInvoke: boolean;
        }) => () => void;
    };
    operation: {
        setPriority: (id: number) => void;
        setHospital: (id: number) => void;
    };
    notification: {
        send: (notification: VehicleServicesNotification) => string;
        remove: (notificationId: string) => void;
    };
    rakel: {
        sendRawRakelAction: (commands: string[]) => void;
    };
    app: {
        putInForeground: () => void;
    };
    map: {
        setNavLayerShape: (id: string, layerShapeData: LayerShape[]) => void;
        setNavLayerPoint: (id: string, layerPointData: LayerPoint[]) => void;
        deleteNavLayer: (id: string) => void;
    };
    "test-utils": {
        inject: <E_1 extends keyof VehicleServicesEventPayloadInterface>(event: E_1, payload?: VehicleServicesEventPayload<E_1> | undefined) => void;
        uncheckedInject: (event: keyof VehicleServicesEventPayloadInterface, payload: unknown) => void;
        initLog: <E_2 extends keyof VehicleServicesEventPayloadInterface>(target?: (event: E_2, payload: VehicleServicesEventPayload<E_2>) => void, errorTarget?: (event: E_2, payload: VehicleServicesEventPayload<E_2>, error: z.ZodError<any>) => void) => void;
        setDocument: (doc?: Document) => void;
        reset: (off?: boolean) => void;
        notification: {
            triggerCallback: (notificationId: string, type?: NotificationCallbackType) => void;
        };
        _internalEvent: {
            on: <E_3 extends keyof _InternalVehicleServicesEventPayloadInterface>(event: E_3, callback: (payload: _InternalVehicleServicesEventPayload<E_3>) => void) => void;
            off: <E_4 extends keyof _InternalVehicleServicesEventPayloadInterface>(event: E_4, callback: (payload: _InternalVehicleServicesEventPayload<E_4>) => void) => void;
        };
    };
};

/**
 * A convenient set of utilities for use in production
 * @ignore
 */
declare const VehicleServicesUtils: {
    /**
     * A collection of different arrays for values of different types within the SDK.
     */
    iterators: {
        displayModes: readonly ["LIGHT", "DARK"];
        notificationTypes: readonly ["LASTING_HUN", "CONCEALED_HUN", "LIMITED_HUN", "QUICK_HUN", "ACTION_HUN"];
        batteryStatuses: readonly ["UNKNOWN", "CHARGING", "DISCHARGING", "NOT_CHARGING", "FULL"];
        batteryHealths: readonly ["UNKNOWN", "GOOD", "OVERHEAT", "DEAD", "OVER_VOLTAGE", "UNSPECIFIED_FAILURE", "COLD"];
        batteryPluggedStates: readonly ["DOCK", "AC", "USB", "WIRELESS"];
        internetStates: readonly ["NO_INTERNET", "CONNECTED_2G", "CONNECTED_EDGE", "CONNECTED_3G", "CONNECTED_4G", "CONNECTED_5G", "CONNECTED_WIFI"];
        operationStates: readonly ["ACTIVE", "AVAILABLE", "COMPLETE"];
        operationUnitSources: readonly ["RAKEL", "CLOUD", "UNKNOWN"];
        vehicleServicesEvents: readonly (keyof VehicleServicesEventPayloadInterface)[];
    };
};

export { type AppId, type AppSettings, type AppVersion, type Battery, type BatteryHealth, type BatteryPlugged, type BatteryStatus, type DestinationControlPointLocation, type DestinationSiteLocation, type DeviceId, type DeviceRole, type DisplayMode, EvamApi, type GrpcAddress, type HospitalLocation, type InternetState, type LatLon, type LayerPoint, type LayerShape, type Location, type NotificationType, type OSVersion, type Operation, type OperationList, type OperationPriority, type OperationState, type OperationUnit, type OperationUnitSource, type RakelState, type TripLocationHistory, type VehicleServicesCallbackIdSuffix, type VehicleServicesEvent, type VehicleServicesEventPayload, type VehicleServicesNotification, type VehicleServicesNotificationButton, type VehicleServicesNotificationCallbackId, type VehicleServicesNotificationId, VehicleServicesUtils, type VehicleServicesVersion, type VehicleState, type VehicleStatus, type VehicleStatusList };
